from .cnb_exchange_rate import monthly_rate
from .cnb_exchange_rate import monthly_cumulative_rate
from .cnb_exchange_rate import quarterly_rate
from .cnb_exchange_rate import daily_rate
from .cnb_exchange_rate import set_host
